Index: c/src/lib/libcpu/ChangeLog
===================================================================
--- c/src/lib/libcpu/ChangeLog	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/ChangeLog	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -1,2 +1,10 @@
+2008-08-31	Joel Sherrill <joel.sherrill@oarcorp.com>
+
+	* arm/at91rm9200/timer/timer.c, arm/lpc22xx/timer/timer.c,
+	arm/mc9328mxl/timer/timer.c, arm/s3c2400/timer/timer.c,
+	arm/s3c24xx/timer/timer.c, bfin/timer/timer.c,
+	m68k/mcf5206/timer/timer.c, m68k/mcf5272/timer/timer.c: Rename timer
+	driver methods to follow RTEMS programming conventions.
+
 2006-08-09	Kolja Waschk <waschk@telos.de>
 
Index: c/src/lib/libcpu/bfin/timer/timer.c
===================================================================
--- c/src/lib/libcpu/bfin/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/bfin/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -89,14 +89,4 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timer_empty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
 void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
Index: c/src/lib/libcpu/m68k/mcf5206/timer/timer.c
===================================================================
--- c/src/lib/libcpu/m68k/mcf5206/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/m68k/mcf5206/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -139,21 +139,4 @@
 }
 
-
-/* benchmark_timer_empty_function --
- *     Empty function call used in loops to measure basic cost of looping
- *     in Timing Test Suite.
- *
- * PARAMETERS:
- *     none
- *
- * RETURNS:
- *     RTEMS_SUCCESSFUL
- */
-rtems_status_code
-benchmark_timer_empty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
 /* benchmark_timer_disable_subtracting_average_overhead --
  *     This routine is invoked by the "Check Timer" (tmck) test in the
Index: c/src/lib/libcpu/m68k/mcf5272/timer/timer.c
===================================================================
--- c/src/lib/libcpu/m68k/mcf5272/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/m68k/mcf5272/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -141,21 +141,4 @@
 }
 
-
-/* benchmark_timer_empty_function --
- *     Empty function call used in loops to measure basic cost of looping
- *     in Timing Test Suite.
- *
- * PARAMETERS:
- *     none
- *
- * RETURNS:
- *     RTEMS_SUCCESSFUL
- */
-rtems_status_code
-benchmark_timer_empty_function(void)
-{
-    return RTEMS_SUCCESSFUL;
-}
-
 /* benchmark_timer_disable_subtracting_average_overhead --
  *     This routine is invoked by the "Check Timer" (tmck) test in the

Index: c/src/lib/libcpu/arm/at91rm9200/timer/timer.c
===================================================================
--- c/src/lib/libcpu/arm/at91rm9200/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/arm/at91rm9200/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -14,6 +14,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -29,5 +29,5 @@
 
 uint16_t tstart;
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 uint32_t tick_time;
 /*
@@ -36,5 +36,5 @@
  *   capture mode - this shouldn't matter
  */
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
     uint32_t tmr_freq;
@@ -53,5 +53,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -67,5 +67,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint16_t t;
@@ -81,5 +81,5 @@
   total = t * tick_time;
 
-  if ( benchmark_timerfind_average_overhead == 1 )
+  if ( benchmark_timer_find_average_overhead == 1 )
     return total;          /* in nanosecond units */
   else {
@@ -93,19 +93,9 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
 
@@ -14,6 +14,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -53,5 +53,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
Index: c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
===================================================================
--- c/src/lib/libcpu/arm/lpc22xx/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/arm/lpc22xx/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -14,6 +14,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -30,5 +30,5 @@
 uint32_t g_freq;
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
     
@@ -36,5 +36,5 @@
  * Set up Timer 1
  */
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
        g_freq = LPC22xx_Fpclk / 1000;
@@ -42,5 +42,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -56,5 +56,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   return (T0TC/(LPC22xx_Fpclk/1000000));
@@ -66,19 +66,9 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
 
@@ -14,6 +14,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -42,5 +42,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
Index: c/src/lib/libcpu/arm/mc9328mxl/timer/timer.c
===================================================================
--- c/src/lib/libcpu/arm/mc9328mxl/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/arm/mc9328mxl/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -15,6 +15,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -31,5 +31,5 @@
 uint32_t g_freq;
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
     
@@ -37,5 +37,5 @@
  * Set up Timer 1
  */
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
     MC9328MXL_TMR2_TCTL = (MC9328MXL_TMR_TCTL_CLKSRC_PCLK1 | 
@@ -52,5 +52,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -66,5 +66,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
   uint32_t t;
@@ -83,5 +83,5 @@
   total = (total * 1000)/ g_freq; 
 
-  if ( benchmark_timerfind_average_overhead == 1 ) {
+  if ( benchmark_timer_find_average_overhead == 1 ) {
     return (int) total; 
   } else if ( total < LEAST_VALID ) {
@@ -95,19 +95,9 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-  return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-  benchmark_timerfind_average_overhead = find_flag;
+  benchmark_timer_find_average_overhead = find_flag;
 }
 
@@ -15,6 +15,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -52,5 +52,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
Index: c/src/lib/libcpu/arm/s3c2400/timer/timer.c
===================================================================
--- c/src/lib/libcpu/arm/s3c2400/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/arm/s3c2400/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -12,6 +12,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -28,5 +28,5 @@
 uint32_t g_freq;
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
     
@@ -34,5 +34,5 @@
  * Set up Timer 1
  */
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
     uint32_t cr;
@@ -59,5 +59,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -73,5 +73,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
     uint32_t t;
@@ -90,5 +90,5 @@
     total = (total*1000) / g_freq; 
 
-    if ( benchmark_timerfind_average_overhead == 1 ) {
+    if ( benchmark_timer_find_average_overhead == 1 ) {
         return (int) total; 
     } else if ( total < LEAST_VALID ) {
@@ -102,19 +102,9 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-    return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-    benchmark_timerfind_average_overhead = find_flag;
+    benchmark_timer_find_average_overhead = find_flag;
 }
 
@@ -12,6 +12,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined 
@@ -59,5 +59,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
Index: c/src/lib/libcpu/arm/s3c24xx/timer/timer.c
===================================================================
--- c/src/lib/libcpu/arm/s3c24xx/timer/timer.c	(revision 19b222386f87a04709dfef74b87442fcf16e725f)
+++ c/src/lib/libcpu/arm/s3c24xx/timer/timer.c	(revision 18bfc42d67fb7cb7b5ba4deebc9448d1c5c36b76)
@@ -12,6 +12,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
  *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
  *  the number of microseconds since benchmark_timerinitialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined
@@ -28,5 +28,5 @@
 uint32_t g_freq;
 
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
 
 
@@ -34,5 +34,5 @@
  * Set up Timer 1
  */
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
 {
     uint32_t cr;
@@ -59,5 +59,5 @@
 
 /*
  *  The following controls the behavior of benchmark_timerread().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It
@@ -73,5 +73,5 @@
 #define LEAST_VALID       1  /* Don't trust a clicks value lower than this */
 
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
 {
     uint32_t t;
@@ -90,5 +90,5 @@
     total = (total*1000) / g_freq;
 
-    if ( benchmark_timerfind_average_overhead == 1 ) {
+    if ( benchmark_timer_find_average_overhead == 1 ) {
         return (int) total;
     } else if ( total < LEAST_VALID ) {
@@ -102,19 +102,9 @@
 }
 
-/*
- *  Empty function call used in loops to measure basic cost of looping
- *  in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
-    return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
   rtems_boolean find_flag
 )
 {
-    benchmark_timerfind_average_overhead = find_flag;
+    benchmark_timer_find_average_overhead = find_flag;
 }
 
@@ -12,6 +12,6 @@
  *  This file manages the benchmark timer used by the RTEMS Timing Test
  *  Suite.  Each measured time period is demarcated by calls to
- *  benchmark_timerinitialize() and benchmark_timerread().  benchmark_timerread() usually returns
- *  the number of microseconds since benchmark_timerinitialize() exitted.
+ *  benchmark_timer_initialize() and benchmark_timer_read().  benchmark_timer_read() usually returns
+ *  the number of microseconds since benchmark_timer_initialize() exitted.
  *
  *  It is important that the timer start/stop overhead be determined
@@ -59,5 +59,5 @@
 
 /*
- *  The following controls the behavior of benchmark_timerread().
+ *  The following controls the behavior of benchmark_timer_read().
  *
  *  AVG_OVEREHAD is the overhead for starting and stopping the timer.  It